@@ -27,13 +27,19 @@ from pymc.exceptions import SamplingError
 from pymc.model import Point, modelcontext
 from pymc.pytensorf import floatX
 from pymc.stats.convergence import SamplerWarning, WarningType
-from pymc.step_methods import step_sizes
 from pymc.step_methods.arraystep import GradientSharedStep
+from pymc.step_methods.compound import StepMethodState
 from pymc.step_methods.hmc import integration
 from pymc.step_methods.hmc.integration import IntegrationError, State
-from pymc.step_methods.hmc.quadpotential import QuadPotentialDiagAdapt, quad_potential
+from pymc.step_methods.hmc.quadpotential import (
+    PotentialState,
+    QuadPotentialDiagAdapt,
+    quad_potential,
+)
+from pymc.step_methods.state import dataclass_state
+from pymc.step_methods.step_sizes import DualAverageAdaptation, StepSizeState
 from pymc.tuning import guess_scaling
-from pymc.util import get_value_vars_from_user_vars
+from pymc.util import RandomGenerator, get_random_generator, get_value_vars_from_user_vars
 
 logger = logging.getLogger(__name__)
 
@@ -52,12 +58,27 @@ class HMCStepData(NamedTuple):
     stats: dict[str, Any]
 
 
+@dataclass_state
+class BaseHMCState(StepMethodState):
+    adapt_step_size: bool
+    Emax: float
+    iter_count: int
+    step_size: np.ndarray
+    step_adapt: StepSizeState
+    target_accept: float
+    tune: bool
+    potential: PotentialState
+    _num_divs_sample: int
+
+
 class BaseHMC(GradientSharedStep):
     """Superclass to implement Hamiltonian/hybrid monte carlo."""
 
     integrator: integration.CpuLeapfrogIntegrator
     default_blocked = True
 
+    _state_class = BaseHMCState
+
     def __init__(
         self,
         vars=None,
@@ -75,6 +96,7 @@ class BaseHMC(GradientSharedStep):
         t0=10,
         adapt_step_size=True,
         step_rand=None,
+        rng=None,
         **pytensor_kwargs,
     ):
         """Set up Hamiltonian samplers with common structures.
@@ -98,6 +120,14 @@ class BaseHMC(GradientSharedStep):
         potential: Potential, optional
             An object that represents the Hamiltonian with methods `velocity`,
             `energy`, and `random` methods.
+        rng: RandomGenerator
+            An object that can produce be used to produce the step method's
+            :py:class:`~numpy.random.Generator` object. Refer to
+            :py:func:`pymc.util.get_random_generator` for more information. The
+            resulting ``Generator`` object will be used stored in the step method
+            and used for accept/reject random selections. The step's ``Generator``
+            will also be used to spawn independent ``Generators`` that will be used
+            by the ``potential`` attribute.
         **pytensor_kwargs: passed to PyTensor functions
         """
         self._model = modelcontext(model)
@@ -106,7 +136,9 @@ class BaseHMC(GradientSharedStep):
             vars = self._model.continuous_value_vars
         else:
             vars = get_value_vars_from_user_vars(vars, self._model)
-        super().__init__(vars, blocked=blocked, model=self._model, dtype=dtype, **pytensor_kwargs)
+        super().__init__(
+            vars, blocked=blocked, model=self._model, dtype=dtype, rng=rng, **pytensor_kwargs
+        )
 
         self.adapt_step_size = adapt_step_size
         self.Emax = Emax
@@ -122,16 +154,14 @@ class BaseHMC(GradientSharedStep):
         size = sum(v.size for v in nuts_vars)
 
         self.step_size = step_scale / (size**0.25)
-        self.step_adapt = step_sizes.DualAverageAdaptation(
-            self.step_size, target_accept, gamma, k, t0
-        )
+        self.step_adapt = DualAverageAdaptation(self.step_size, target_accept, gamma, k, t0)
         self.target_accept = target_accept
         self.tune = True
 
         if scaling is None and potential is None:
             mean = floatX(np.zeros(size))
             var = floatX(np.ones(size))
-            potential = QuadPotentialDiagAdapt(size, mean, var, 10)
+            potential = QuadPotentialDiagAdapt(size, mean, var, 10, rng=self.rng.spawn(1)[0])
 
         if isinstance(scaling, dict):
             point = Point(scaling, model=self._model)
@@ -143,7 +173,7 @@ class BaseHMC(GradientSharedStep):
         if potential is not None:
             self.potential = potential
         else:
-            self.potential = quad_potential(scaling, is_cov)
+            self.potential = quad_potential(scaling, is_cov, rng=self.rng.spawn(1)[0])
 
         self.integrator = integration.CpuLeapfrogIntegrator(self.potential, self._logp_dlogp_func)
 
@@ -193,7 +223,7 @@ class BaseHMC(GradientSharedStep):
         self.step_size = step_size
 
         if self._step_rand is not None:
-            step_size = self._step_rand(step_size)
+            step_size = self._step_rand(step_size, rng=self.rng)
 
         hmc_step = self._hamiltonian_step(start, p0.data, step_size)
 
@@ -256,3 +286,7 @@ class BaseHMC(GradientSharedStep):
     def reset(self, start=None):
         self.tune = True
         self.potential.reset()
+
+    def set_rng(self, rng: RandomGenerator):
+        self.rng = get_random_generator(rng, copy=False)
+        self.potential.set_rng(self.rng.spawn(1)[0])
