@@ -40,13 +40,15 @@ __all__ = ["MeanField", "FullRank", "Empirical", "sample_approx"]
 
 @Group.register
 class MeanFieldGroup(Group):
-    R"""Mean Field approximation to the posterior where spherical Gaussian family
-    is fitted to minimize KL divergence from True posterior. It is assumed
-    that latent space variables are uncorrelated that is the main drawback
-    of the method
+    """Mean Field approximation to the posterior.
+
+    Spherical Gaussian family is fitted to minimize KL divergence from posterior.
+
+    It is assumed that latent space variables are uncorrelated that is the main
+    drawback of the method.
     """
 
-    __param_spec__ = dict(mu=("d",), rho=("d",))
+    __param_spec__ = {"mu": ("d",), "rho": ("d",)}
     short_name = "mean_field"
     alias_names = frozenset(["mf"])
 
@@ -116,13 +118,15 @@ class MeanFieldGroup(Group):
 
 @Group.register
 class FullRankGroup(Group):
-    """Full Rank approximation to the posterior where Multivariate Gaussian family
-    is fitted to minimize KL divergence from True posterior. In contrast to
-    MeanField approach correlations between variables are taken in account. The
-    main drawback of the method is computational cost.
+    """Full Rank approximation to the posterior.
+
+    Multivariate Gaussian family is fitted to minimize KL divergence from posterior.
+
+    In contrast to MeanField approach, correlations between variables are taken
+    into account. The main drawback of the method is its computational cost.
     """
 
-    __param_spec__ = dict(mu=("d",), L_tril=("int(d * (d + 1) / 2)",))
+    __param_spec__ = {"mu": ("d",), "L_tril": ("int(d * (d + 1) / 2)",)}
     short_name = "full_rank"
     alias_names = frozenset(["fr"])
 
@@ -188,19 +192,20 @@ class FullRankGroup(Group):
 
 @Group.register
 class EmpiricalGroup(Group):
-    """Builds Approximation instance from a given trace,
-    it has the same interface as variational approximation
+    """Builds Approximation instance from a given trace.
+
+    It has the same interface as variational approximation.
     """
 
     has_logq = False
-    __param_spec__ = dict(histogram=("s", "d"))
+    __param_spec__ = {"histogram": ("s", "d")}
     short_name = "empirical"
 
     @pytensor.config.change_flags(compute_test_value="off")
     def __init_group__(self, group):
         super().__init_group__(group)
         self._check_trace()
-        if not self._check_user_params(spec_kw=dict(s=-1)):
+        if not self._check_user_params(spec_kw={"s": -1}):
             self.shared_params = self.create_shared_params(
                 trace=self._kwargs.get("trace", None),
                 size=self._kwargs.get("size", None),
@@ -225,7 +230,7 @@ class EmpiricalGroup(Group):
                 for j in range(len(trace)):
                     histogram[i] = DictToArrayBijection.map(trace.point(j, t)).data
                     i += 1
-        return dict(histogram=pytensor.shared(pm.floatX(histogram), "histogram"))
+        return {"histogram": pytensor.shared(pm.floatX(histogram), "histogram")}
 
     def _check_trace(self):
         trace = self._kwargs.get("trace", None)
@@ -236,7 +241,7 @@ class EmpiricalGroup(Group):
                 " Please help us to refactor: https://github.com/pymc-devs/pymc/issues/5884"
             )
         elif trace is not None and not all(
-            [self.model.rvs_to_values[var].name in trace.varnames for var in self.group]
+            self.model.rvs_to_values[var].name in trace.varnames for var in self.group
         ):
             raise ValueError("trace has not all free RVs in the group")
 
@@ -330,7 +335,7 @@ def sample_approx(approx, draws=100, include_transformed=True):
 
 # single group shortcuts exported to user
 class SingleGroupApproximation(Approximation):
-    """Base class for Single Group Approximation"""
+    """Base class for Single Group Approximation."""
 
     _group_class: type | None = None
 
@@ -344,7 +349,7 @@ class SingleGroupApproximation(Approximation):
     def __dir__(self):
         d = set(super().__dir__())
         d.update(self.groups[0].__dir__())
-        return list(sorted(d))
+        return sorted(d)
 
 
 class MeanField(SingleGroupApproximation):
@@ -372,7 +377,7 @@ class Empirical(SingleGroupApproximation):
 
     def evaluate_over_trace(self, node):
         R"""
-        Allows to statically evaluate any symbolic expression over the trace.
+        Allow to statically evaluate any symbolic expression over the trace.
 
         Parameters
         ----------
