@@ -36,14 +36,15 @@ class TestNUTSUniform(sf.NutsFixture, sf.UniformFixture):
     min_n_eff = 9000
     rtol = 0.1
     atol = 0.05
+    step_args = {"random_seed": 202010}
 
 
 class TestNUTSUniform2(TestNUTSUniform):
-    step_args = {"target_accept": 0.95}
+    step_args = {"target_accept": 0.95, "random_seed": 202010}
 
 
 class TestNUTSUniform3(TestNUTSUniform):
-    step_args = {"target_accept": 0.80}
+    step_args = {"target_accept": 0.80, "random_seed": 202010}
 
 
 class TestNUTSNormal(sf.NutsFixture, sf.NormalFixture):
@@ -54,6 +55,7 @@ class TestNUTSNormal(sf.NutsFixture, sf.NormalFixture):
     min_n_eff = 10000
     rtol = 0.1
     atol = 0.05
+    step_args = {"random_seed": 123456}
 
 
 class TestNUTSBetaBinomial(sf.NutsFixture, sf.BetaBinomialFixture):
@@ -63,6 +65,7 @@ class TestNUTSBetaBinomial(sf.NutsFixture, sf.BetaBinomialFixture):
     burn = 0
     chains = 2
     min_n_eff = 400
+    step_args = {"random_seed": 202010}
 
 
 class TestNUTSStudentT(sf.NutsFixture, sf.StudentTFixture):
@@ -73,6 +76,7 @@ class TestNUTSStudentT(sf.NutsFixture, sf.StudentTFixture):
     min_n_eff = 1000
     rtol = 0.1
     atol = 0.05
+    step_args = {"random_seed": 202010}
 
 
 @pytest.mark.skip("Takes too long to run")
@@ -92,6 +96,7 @@ class TestNUTSLKJCholeskyCov(sf.NutsFixture, sf.LKJCholeskyCovFixture):
     burn = 0
     chains = 2
     min_n_eff = 200
+    step_args = {"random_seed": 202010}
 
 
 class TestNutsCheckTrace:
